#
# Principal Component Analysis in Python
#


#
# Load the required libraries. 
# Make sure that you installed properly the sklearn module that contains
# the required functions and datasets
#


#Next two lines required to load the PCA function
from sklearn import decomposition
from sklearn.decomposition import PCA

# sklearn comes with datasets. Make them available to this program
from sklearn import datasets

# Load the iris dataset
iris = datasets.load_iris()

# Get the data of the iris dataset into a new variable
irisDataset = iris.data

# Initialize the PCA function of the sklearn module.
# Here, we say how many principal components we want. We will require
# only 2 principal components
pca = decomposition.PCA(n_components=2)


# Here we actually apply PCA to the iris dataset.
# After executing PCA on the dataset, you can examine the properties
# of the pca object to get the necessary information
pca.fit(irisDataset)

# Show now the eingenvectors. To do this,
# you may access the property .components_ like so
print("Eigenvectors:")
print(pca.components_)

# Now transform the data of the iris dataset to the new coordinate system,
# defined by the two Eigenvectors that resulted from PCA
transformedIrisDataset = pca.transform(irisDataset)

# Print out the new data when the original data
# is mapped onto the Eigenvectors. Please not that
# since we asked for 2 components (n_components=2)
# the original four dimensional data will be mapped on
# a two dimensional space, defined by the two Eigenvectors
print("\nNew data points, on the space defined by the Eigenvectors")
print( transformedIrisDataset)
